pub fn triangulate_points<'a, I>(points: I) -> TriangleVecExpand description
Triangulates an iterator of points. This is a shortcut for the most common operation.
pub fn triangulate_points<'a, I>(points: I) -> TriangleVecTriangulates an iterator of points. This is a shortcut for the most common operation.